@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Lump;
 
-our $DATE = '2015-05-16'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-08-31'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -170,8 +170,10 @@ sub munge_file {
     my $content = $file->content;
     my $munged = 0;
 
-    $munged++ if $content =~ s/^(#\s*LUMPED_MODULES)/"our \@LUMPED_MODULES = \@{" . dmp($self->{_lump_mods}) . "}; $1"/em;
-    $munged++ if $content =~ s/^(#\s*LUMPED_DISTS)/"our \@LUMPED_DISTS = \@{" . dmp($self->{_lump_dists}) . "}; $1"/em;
+    $munged++ if $content =~ s/^(#\s*LUMPED_MODULES)$/"our \@LUMPED_MODULES = \@{" . dmp($self->{_lump_mods} ) . "}; $1"/em;
+    $munged++ if $content =~ s/^(#\s*LUMPED_DISTS)$/  "our \@LUMPED_DISTS   = \@{" . dmp($self->{_lump_dists}) . "}; $1"/em;
+    $munged++ if $content =~ s/^(#\s*LUMPED_MODULES_POD)$/"=over\n\n" . join("", map { "=item * $_\n\n" } @{ $self->{_lump_mods}  }) . "=back\n\n"/em;
+    $munged++ if $content =~ s/^(#\s*LUMPED_DISTS_POD)$/  "=over\n\n" . join("", map { "=item * $_\n\n" } @{ $self->{_lump_dists} }) . "=back\n\n"/em;
     $file->content($content) if $munged;
 }
 
@@ -197,7 +199,7 @@ Dist::Zilla::Plugin::Lump - Lump other modules/dists together into dist
 
 =head1 VERSION
 
-This document describes version 0.08 of Dist::Zilla::Plugin::Lump (from Perl distribution Dist-Zilla-Plugin-Lump), released on 2015-05-16.
+This document describes version 0.09 of Dist::Zilla::Plugin::Lump (from Perl distribution Dist-Zilla-Plugin-Lump), released on 2015-08-31.
 
 =head1 SYNOPSIS
 
@@ -232,6 +234,47 @@ In your main module, e.g. L<lib/Perinci/CmdLine/Any/Lumped.pm>:
 
  ...
 
+And in the built version the directives will be replaced with:
+
+ our @LUMPED_MODULES = (...); # LUMPED_MODULES
+ our @LUMPED_DISTS = (...); # LUMPED_DISTS
+
+You can also add in the POD area:
+
+ =head1 LIST OF LUMPED MODULES
+
+ # LUMPED_MODULES_POD
+
+ =head1 LIST OF LUMPED DISTS
+
+ # LUMPED_DISTS_POD
+
+And in the built version they will become:
+
+ =head1 LIST OF LUMPED MODULES
+
+ =over
+
+ =item * ...
+
+ =item * ...
+
+ ...
+
+ =back
+
+ =head1 LIST OF LUMPED DISTS
+
+ =over
+
+ =item * ...
+
+ =item * ...
+
+ ...
+
+ =back
+
 =head1 DESCRIPTION
 
 B<WARNING: EXPERIMENTAL>
